**thermofeel** is a library to calculate human thermal comfort indexes.

Currently available indexes:
 * Relative Humidity Percentage
 * Relative Humidity [pa]
 * Heat Index Simplified
 * Heat Index Adjusted
 * Solar Zenith Angle
 * Mean Radiant Temperature
 * Universal Thermal Climate Index
 * Wet Bulb Globe Temperature Simple
 * Wet Bulb Globe Temperature
 * Mean Radiant Temperature from Wet Bulb Globe Temperature
 * Humidex
 * Net Effective Temperature
 * Apparent Temperature
 * and Wind Chill

Installation
============

The package is installed from PyPI with::

    $ pip install thermofeel


System dependencies
-------------------

thermofeel core functions depend on:
 * numpy

Contributing
============

The main repository is hosted on GitHub, testing, bug reports and contributions are highly welcomed and appreciated:

https://github.com/ecmwf-projects/thermofeel

Please see the CONTRIBUTING.rst document for the best way to help.

Lead developer:

- Chloe Brimicombe - `ECMWF <https://ecmwf.int>`_

Main contributors:

- Tiago Quintino - `ECMWF <https://ecmwf.int>`_

See also the list of `contributors <https://github.com/ecmwf-projects/thermofeel/contributors>`_ who participated in this project.


License
=======

Copyright 2021 European Centre for Medium-Range Weather Forecasts (ECMWF)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

In applying this licence, ECMWF does not waive the privileges and immunities
granted to it by virtue of its status as an intergovernmental organisation nor
does it submit to any jurisdiction.
